@@ -17,8 +17,6 @@
 */
 #include <Models/MultinomialModel.hpp>
 #include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <Models/DirichletModel.hpp>
-#include <Models/PosteriorSamplers/MultinomialDirichletSampler.hpp>
 #include <Models/SufstatAbstractCombineImpl.hpp>
 
 #include <distributions.hpp>
@@ -32,101 +30,103 @@ namespace BOOM{
   typedef MultinomialSuf MS;
   typedef CategoricalData CD;
   MS::MultinomialSuf(const uint p)
-    : counts(p, 0.0)
+    : counts_(p, 0.0)
   {}
 
+  MS::MultinomialSuf(const Vector &counts)
+      : counts_(counts)
+  {
+    if (counts.min() < 0.0) {
+      report_error("All elements of counts must be non-negative.");
+    }
+  }
+
   MS::MultinomialSuf(const MultinomialSuf &rhs)
     : Sufstat(rhs),
       SufstatDetails<CD>(rhs),
-      counts(rhs.counts)
+      counts_(rhs.counts_)
   {}
 
   MS * MS::clone()const{return new MS(*this);}
 
   void MS::Update(const CD &d){
     uint i = d.value();
-    while(i>=counts.size()) counts.push_back(0);  // counts grows when needed
-    ++counts[i]; }
-
-  void MS::add_mixture_data(uint y, double prob){
-    counts[y]+=prob;
+    while(i>=counts_.size()) {
+      counts_.push_back(0);  // counts_ grows when needed
+    }
+    ++counts_[i];
   }
 
-  void MS::add_mixture_data(const Vector &weights) {
-    counts += weights;
-  }
+  void MS::add_mixture_data(uint y, double prob){ counts_[y]+=prob; }
+  void MS::add_mixture_data(const Vector &weights) { counts_ += weights; }
+  void MS::update_raw(uint k){ ++counts_[k]; }
+  void MS::clear(){ counts_ = 0.0; }
+  const Vector &MS::n()const{ return counts_; }
+  uint MS::dim() const { return counts_.size(); }
+  void MS::combine(Ptr<MS> s){ counts_ += s->counts_; }
+  void MS::combine(const MS & s){ counts_ += s.counts_; }
 
-  void MS::update_raw(uint k){ ++counts[k]; }
-
-  void MS::clear(){counts=0.0;}
-
-  const Vec &MS::n()const{return counts;}
-
-  void MS::combine(Ptr<MS> s){ counts += s->counts; }
-  void MS::combine(const MS & s){ counts += s.counts; }
   MultinomialSuf * MS::abstract_combine(Sufstat *s){
-    return abstract_combine_impl(this,s); }
-
-  Vec MS::vectorize(bool)const{
-    return counts;
+    return abstract_combine_impl(this,s);
   }
+  Vector MS::vectorize(bool)const{return counts_; }
 
-  Vec::const_iterator MS::unvectorize(Vec::const_iterator &v,
+  Vector::const_iterator MS::unvectorize(Vector::const_iterator &v,
                                       bool){
-    uint dim = counts.size();
-    counts.assign(v, v+dim);
+    uint dim = counts_.size();
+    counts_.assign(v, v+dim);
     v+=dim;
     return v;
   }
 
-  Vec::const_iterator MS::unvectorize(const Vec &v, bool minimal){
-    Vec::const_iterator it = v.begin();
+  Vector::const_iterator MS::unvectorize(const Vector &v, bool minimal){
+    Vector::const_iterator it = v.begin();
     return unvectorize(it,minimal);
   }
 
   ostream & MS::print(ostream &out)const{
-    return out << counts;
+    return out << counts_;
   }
   //======================================================================
 
   typedef MultinomialModel MM;
-  typedef std::vector<string> StringVec;
+  typedef std::vector<string> StringVector;
 
   MM::MultinomialModel(uint p)
     : ParamPolicy(new VectorParams(p, 1.0/p)),
       DataPolicy(new MS(p)),
-      ConjPriorPolicy(),
+      PriorPolicy(),
       logp_current_(false)
   {
     set_observer();
   }
 
-  uint  count_levels(const StringVec &sv){
+  uint  count_levels(const StringVector &sv){
     std::set<string> s;
     for(uint i=0; i<sv.size(); ++i) s.insert(sv[i]);
     return s.size();
   }
 
-  MM::MultinomialModel(const Vec &probs)
+  MM::MultinomialModel(const Vector &probs)
     : ParamPolicy(new VectorParams(probs)),
       DataPolicy(new MS(probs.size())),
-      ConjPriorPolicy(),
+      PriorPolicy(),
       logp_current_(false)
   {
     set_observer();
   }
 
-  MM::MultinomialModel(const StringVec &names)
+  MM::MultinomialModel(const StringVector &names)
     : ParamPolicy(new VectorParams(1)),
       DataPolicy(new MS(1)),
-      ConjPriorPolicy(),
+      PriorPolicy(),
       logp_current_(false)
   {
     std::vector<Ptr<CD> >
       dvec(make_catdat_ptrs(names));
 
     uint nlev= dvec[0]->nlevels();
-    Vec probs(nlev, 1.0/nlev);
+    Vector probs(nlev, 1.0/nlev);
     set_pi(probs);
 
     set_data(dvec);
@@ -134,13 +134,23 @@ namespace BOOM{
     set_observer();
   }
 
+  MM::MultinomialModel(const MultinomialSuf &suf)
+      : ParamPolicy(new VectorParams(suf.dim())),
+        DataPolicy(new MS(suf)),
+        PriorPolicy(),
+        logp_current_(false)
+  {
+    set_observer();
+    mle();
+  }
+
   MM::MultinomialModel(const MM &rhs)
     : Model(rhs),
       ParamPolicy(rhs),
       DataPolicy(rhs),
-      ConjPriorPolicy(rhs),
+      PriorPolicy(rhs),
       LoglikeModel(rhs),
-      EmMixtureComponent(rhs),
+      MixtureComponent(rhs),
       logp_current_(false)
   {
     set_observer();
@@ -159,26 +169,26 @@ namespace BOOM{
 
   uint MM::nlevels()const{return pi().size();}
   const double & MM::pi(int s) const{ return pi()[s];}
-  const Vec & MM::pi()const{return Pi_prm()->value();}
-  void MM::set_pi(const Vec &probs){
+  const Vector & MM::pi()const{return Pi_prm()->value();}
+  void MM::set_pi(const Vector &probs){
     Pi_prm()->set(probs);
     check_logp();
   }
 
-  uint MM::size()const{return pi().size();}
+  uint MM::dim()const{return pi().size();}
 
   double MM::loglike(const Vector &probs)const{
     double ans(0.0);
-    const Vec &n(suf()->n());
-    for(uint i=0; i<size(); ++i)ans+= n[i]*log(probs[i]);
+    const Vector &n(suf()->n());
+    for(uint i=0; i<dim(); ++i)ans+= n[i]*log(probs[i]);
     return ans;
   }
 
   void MM::mle(){
-    const Vec &n(suf()->n());
+    const Vector &n(suf()->n());
     double tot = sum(n);
     if(tot==0){
-      Vec probs(size(), 1.0/size());
+      Vector probs(dim(), 1.0/dim());
       set_pi(probs);
       return;
     }
@@ -188,9 +198,9 @@ namespace BOOM{
   double MM::pdf(const Data * dp, bool logscale)const{
     check_logp();
     uint i = DAT(dp)->value();
-    if(i >=size()){
+    if(i >= dim()){
       string msg = "too large a value passed to MultinomialModel::pdf";
-      throw_exception<std::runtime_error>(msg);
+      report_error(msg);
     }
     return logscale ? logp_[i] : pi(i);
   }
@@ -198,9 +208,9 @@ namespace BOOM{
   double MM::pdf(Ptr<Data> dp, bool logscale)const{
     check_logp();
     uint i = DAT(dp)->value();
-    if(i >=size()){
+    if(i >= dim()){
       string msg = "too large a value passed to MultinomialModel::pdf";
-      throw_exception<std::runtime_error>(msg);
+      report_error(msg);
     }
     return logscale ? logp_[i] : pi(i);
   }
@@ -212,20 +222,6 @@ namespace BOOM{
     suf()->add_mixture_data(i,prob);
   }
 
-  void MM::set_conjugate_prior(const Vec &nu){
-    NEW(MultinomialDirichletSampler, sam)(this, nu);
-    this->set_conjugate_prior(sam);
-  }
-
-  void MM::set_conjugate_prior(Ptr<DirichletModel> dir){
-    NEW(MultinomialDirichletSampler, sam)(this, dir);
-    ConjPriorPolicy::set_conjugate_prior(sam);
-  }
-
-  void MM::set_conjugate_prior(Ptr<MultinomialDirichletSampler> sam){
-    ConjPriorPolicy::set_conjugate_prior(sam);
-  }
-
   void MM::observe_logp(){
     logp_current_ = false;
   }
