@@ -26,20 +26,20 @@
 namespace BOOM{
   double sparse_scalar_kalman_update(
       double y,                         // New observation at time t
-      Vec &a,                           // Input a[t].  Output a[t+1]
-      Spd &P,                           // Input P[t].  Ouput P[t+1]
-      Vec &K,                           // Output K[t] Kalman gain
+      Vector &a,                        // Input a[t].  Output a[t+1]
+      SpdMatrix &P,                     // Input P[t].  Ouput P[t+1]
+      Vector &K,                        // Output K[t] Kalman gain
       double &F,                        // Output F[t] Forecast variance
       double &v,                        // Output v[t] Forecast error
       bool missing,                     // true if y[t] is missing
       const SparseVector & Z,           // Model matrix for obs. equation
       double H,                         // Var(Y | state)
       const SparseKalmanMatrix & T,     // State transition matrix
-      const SparseKalmanMatrix & RQR){  // State variance matrix
+      const SparseKalmanMatrix & RQR) { // State variance matrix
 
-    Vec PZ = P*Z;
+    Vector PZ = P*Z;
     F = Z.dot(PZ) + H;
-    if(F <= 0) {
+    if (F <= 0) {
       std::ostringstream err;
       err << "Found a zero forecast variance:" << endl
           << "missing = " << missing << endl
@@ -51,10 +51,10 @@ namespace BOOM{
           << "Z = " << Z.dense() << endl;
       report_error(err.str());
     }
-    Vec TPZ = T * PZ;
+    Vector TPZ = T * PZ;
 
     double loglike=0;
-    if(!missing){
+    if (!missing) {
       K = TPZ/F;
       double mu = Z.dot(a);
       v = y-mu;
@@ -64,15 +64,52 @@ namespace BOOM{
       v = 0;
     }
 
-    a = T * a;                      // Sparse multiplication
-    if(!missing) a.axpy(K, v);      // a += K * v
-    T.sandwich_inplace(P);          // P = T P T.transpose()
-    if(!missing){                   // K is zero if missing, so skip this
-      P.Mat::add_outer(TPZ, K, -1); // P-= T*P*Z*K.transpose();
+    a = T * a;                         // Sparse multiplication
+    if (!missing) a.axpy(K, v);         // a += K * v
+    T.sandwich_inplace(P);             // P = T P T.transpose()
+    if (!missing) {                      // K is zero if missing, so skip this
+      P.Matrix::add_outer(TPZ, K, -1); // P-= T*P*Z*K.transpose();
     }
-    RQR.add_to(P);                  // P += RQR
+    RQR.add_to(P);                     // P += RQR
 
     return loglike;
   }
 
+  // For the math behind this update, see Durbin and Koopman, second
+  // edition, page 95, Section 4.5.3.
+  void sparse_scalar_kalman_disturbance_smoother_update(
+      Vector &scaled_residual_r,
+      SpdMatrix &scaled_residual_variance_N,
+      const SparseKalmanMatrix &transition_matrix_T,
+      const Vector &kalman_gain_K,
+      const SparseVector &observation_matrix_Z,
+      double forecast_variance,
+      double forecast_error) {
+
+    // u[t] = F[t]^{-1} * v[t] - K[t].dot(r[t])
+    double u = forecast_error / forecast_variance
+        - kalman_gain_K.dot(scaled_residual_r);
+    // r[t-1] = T'r + Z*u
+    Vector previous_r = transition_matrix_T.Tmult(scaled_residual_r);
+    observation_matrix_Z.add_this_to(previous_r, u);
+    scaled_residual_r = previous_r;
+
+    double D = 1.0 / forecast_variance
+        + scaled_residual_variance_N.Mdist(kalman_gain_K);
+    SpdMatrix previousN = scaled_residual_variance_N;
+    transition_matrix_T.sandwich_inplace_transpose(previousN);
+    observation_matrix_Z.add_outer_product(previousN, D);
+
+    Vector TprimeNK = transition_matrix_T.Tmult(
+        scaled_residual_variance_N * kalman_gain_K);
+    Matrix TprimeNKZ = observation_matrix_Z.outer_product_transpose(TprimeNK);
+    // Next, previousN = previousN - TprimeNKZ - TprimeNKZ.transpose().
+    // Doing it this way should maximize the use of blas routines.
+    previousN -= TprimeNKZ;
+    for (int i = 0; i < ncol(previousN); ++i) {
+      previousN.col(i) -= TprimeNKZ.row(i);
+    }
+    scaled_residual_variance_N = previousN;
+  }
+
 }
