@@ -20,6 +20,7 @@
 #include <iomanip>
 #include <iostream>
 #include <set>
+#include <tuple>
 
 #include <BOOM.hpp>
 #include <cpputil/make_unique_preserve_order.hpp>
@@ -63,7 +64,7 @@ namespace BOOM{
     Configuration config(xp.nlevels());
     int nr = xp.nconfigurations();
     int nc = builder.dimension();
-    Mat X(nr, nc);
+    Matrix X(nr, nc);
     int i = 0;
     while (!config.done()) {
       X.row(i++) = builder.build_row(config.levels());
@@ -75,6 +76,54 @@ namespace BOOM{
     return ans;
   }
 
+  LabeledMatrix generate_contextual_design_matrix(
+      const ExperimentStructure &context_structure,
+      const ContextualRowBuilder &builder) {
+    Configuration configuration(context_structure.nlevels());
+    std::vector<std::vector<int> > context_configurations;
+    while (!configuration.done()) {
+      context_configurations.push_back(configuration.levels());
+      configuration.next();
+    }
+    std::vector<int> dummy_experimental_configuration(
+        builder.number_of_experimental_factors(), 0);
+    Matrix design(context_configurations.size(), builder.dimension());
+    for (int i = 0; i < context_configurations.size(); ++i) {
+      design.row(i) = builder.build_row(
+          dummy_experimental_configuration,
+          context_configurations[i]);
+    }
+    Selector pure_context = builder.pure_context();
+    LabeledMatrix ans(pure_context.select_cols(design),
+                      std::vector<std::string>(),
+                      pure_context.select(builder.variable_names()));
+    return ans;
+  }
+
+  LabeledMatrix generate_experimental_design_matrix(
+      const ExperimentStructure &xp,
+      const ContextualRowBuilder &builder) {
+    Configuration configuration(xp.nlevels());
+    std::vector<std::vector<int> > configurations;
+    while (!configuration.done()) {
+      configurations.push_back(configuration.levels());
+      configuration.next();
+    }
+    std::vector<int> dummy_context_configuration(
+        builder.number_of_contextual_factors(), 0);
+    Matrix design(configurations.size(), builder.dimension());
+    for (int i = 0; i < configurations.size(); ++i) {
+      design.row(i) = builder.build_row(
+          configurations[i],
+          dummy_context_configuration);
+    }
+    Selector pure_experiment = builder.pure_experiment();
+    LabeledMatrix ans(pure_experiment.select_cols(design),
+                      std::vector<std::string>(),
+                      pure_experiment.select(builder.variable_names()));
+    return ans;
+  }
+
   ExperimentStructure::ExperimentStructure(const std::vector<int> & nlevels)
       : nlevels_(nlevels)
   {
@@ -379,6 +428,17 @@ namespace BOOM{
     }
   }
 
+  ContextualEffect::ContextualEffect(const Effect &effect,
+                                     bool is_context) {
+    for (int i = 0; i < effect.order(); ++i) {
+      if (is_context) {
+        add_context_factor(effect.factor(i));
+      } else {
+        add_experiment_factor(effect.factor(i));
+      }
+    }
+  }
+
   ContextualEffect::ContextualEffect(const ContextualEffect &first,
                                      const ContextualEffect &second)
       : experiment_effect_(first.experiment_effect_),
@@ -501,6 +561,16 @@ namespace BOOM{
     return experiment_effect_.is_valid() & context_effect_.is_valid();
   }
 
+  const FactorDummy & ContextualEffect::experiment_factor(
+      int internal_factor_number) const {
+    return experiment_effect_.factor(internal_factor_number);
+  }
+
+  const FactorDummy & ContextualEffect::context_factor(
+      int internal_factor_number) const {
+    return context_effect_.factor(internal_factor_number);
+  }
+
   const FactorDummy & ContextualEffect::factor_dummy_for_experiment_factor(
       int factor_position_in_input_data) const {
     return experiment_effect_.factor_dummy_for_factor(
@@ -936,9 +1006,277 @@ namespace BOOM{
         int first_level = effects_[i].factor_dummy_for_factor(
             first_factor).level();
         int second_level = effects_[i].factor_dummy_for_factor(
-            second_factor).level();
-        ans[first_level - 1][second_level - 1] = i;
+             second_factor).level();
+         ans[first_level - 1][second_level - 1] = i;
+         found_an_interaction = true;
+       }
+     }
+     if (!found_an_interaction) {
+       // Return an empty vector if there are no interactions between
+       // these factors at all.
+       std::vector<std::vector<int> > empty;
+       return empty;
+     }
+     return ans;
+   }
+
+   const Effect & RowBuilder::effect(int i) const {
+     return effects_[i];
+   }
+
+   Vector RowBuilder::build_row(const std::vector<int> &levels)  const {
+     int neffects = effects_.size();
+     Vector ans(neffects);
+     for (int i = 0; i < neffects; ++i) ans[i] = effects_[i].eval(levels);
+     return ans;
+   }
+
+   void RowBuilder::recover_configuration(
+       const ConstVectorView &design_matrix_row,
+       std::vector<int> &configuration) const {
+     for (int i = 0; i < effects_.size(); ++i) {
+       if (design_matrix_row[i] >= .9999) {
+         effects_[i].set_levels(configuration);
+       }
+     }
+   }
+
+   void RowBuilder::recover_configuration(
+       const Vector &design_matrix_row,
+       std::vector<int> &configuration) const {
+     recover_configuration(ConstVectorView(design_matrix_row), configuration);
+   }
+
+   int RowBuilder::dimension() const { return effects_.size(); }
+
+   std::vector<string> RowBuilder::variable_names() const {
+     std::vector<string> ans;
+     int neffects = effects_.size();
+     ans.reserve(neffects);
+     for (int i = 0; i < neffects; ++i) { ans.push_back(effects_[i].name()); }
+     return ans;
+   }
+
+   //======================================================================
+   ContextualRowBuilder::ContextualRowBuilder(
+       const ExperimentStructure &xp,
+       const ExperimentStructure &context,
+       int interaction_order)
+   {
+     ContextualEffect Intercept;
+     contextual_effects_.push_back(Intercept);
+     if (interaction_order == 0) return;
+     if (interaction_order > xp.nfactors() + context.nfactors()) {
+       interaction_order = xp.nfactors() + context.nfactors();
+     }
+
+     std::vector<ContextualEffect> main_effects;
+     for (int factor = 0; factor < xp.nfactors(); ++factor) {
+       for (int level = 1; level < xp.nlevels(factor); ++level) {
+         FactorDummy dummy(
+             factor,
+             level,
+             xp.full_level_name(factor, level, "."));
+         ContextualEffect main_effect(dummy, false);
+         main_effects.push_back(main_effect);
+         contextual_effects_.push_back(main_effect);
+       }
+     }
+     for (int factor = 0; factor < context.nfactors(); ++factor) {
+       for (int level = 1; level < context.nlevels(factor); ++level) {
+         FactorDummy dummy(
+             factor,
+             level, context.full_level_name(factor, level, "."));
+         ContextualEffect main_effect(dummy, true);
+         main_effects.push_back(main_effect);
+         contextual_effects_.push_back(main_effect);
+       }
+     }
+
+     int number_of_main_effects = main_effects.size();
+
+     std::vector<ContextualEffect> last_effects = main_effects;
+     for (int order = 2; order <= interaction_order; ++order) {
+       std::vector<ContextualEffect> current_effects;
+       for (int i = 0; i < number_of_main_effects; ++i) {
+         ContextualEffect main_effect = main_effects[i];
+         for (int j = 0; j < last_effects.size(); ++j) {
+           ContextualEffect lower_order = last_effects[j];
+           if (lower_order.shares_factors_with(main_effect)) {
+             continue;
+           }
+           ContextualEffect interaction(main_effect, lower_order);
+           if (has_effect(interaction)) {
+             continue;
+           }
+           current_effects.push_back(interaction);
+           contextual_effects_.push_back(interaction);
+         }
+       }
+       last_effects = current_effects;
+     }
+   }
+
+   void ContextualRowBuilder::add_effect(const ContextualEffect &e) {
+     contextual_effects_.push_back(e);
+   }
+
+  void ContextualRowBuilder::add_effect_group(
+      const ContextualEffectGroup &group) {
+    const std::vector<ContextualEffect> &effects(group.effects());
+    for (int i = 0; i < effects.size(); ++i) {
+      add_effect(effects[i]);
+    }
+  }
+
+   int ContextualRowBuilder::dimension() const {
+     return contextual_effects_.size();
+   }
+
+   std::vector<string> ContextualRowBuilder::variable_names() const {
+     std::vector<string> ans;
+     int neffects = contextual_effects_.size();
+     ans.reserve(neffects);
+     for (int i = 0; i < neffects; ++i) {
+       ans.push_back(contextual_effects_[i].name());
+     }
+     return ans;
+   }
+
+   std::vector<int> ContextualRowBuilder::main_effect_positions(
+       int which_factor,
+       bool contextual) const {
+     std::vector<int> ans;
+     for (int i = 0; i < contextual_effects_.size(); ++i) {
+      const ContextualEffect &effect(contextual_effects_[i]);
+      if (contextual) {
+        // Check effect i to see if it is a contextual main effect
+        // corresponding to contextual factor 'which_factor.'  If so,
+        // record its position.
+        if (effect.context_order() == 1 &&
+            effect.experiment_order() == 0 &&
+            effect.models_context_factor(which_factor)) {
+          ans.push_back(i);
+        }
+      } else {
+        // Check effect i to see if it is an experimental main effect
+        // modeling 'which_factor'.  If so, record its position.
+        if (effect.context_order() == 0 &&
+            effect.experiment_order() == 1 &&
+            effect.models_experiment_factor(which_factor)) {
+          ans.push_back(i);
+        }
+      }
+    }
+    return ans;
+  }
+
+  // Find the largest observed factor level for the first and second
+  // factor s.
+  int ContextualRowBuilder::find_max_observed_level(
+      int factor,
+      bool contextual) const {
+    int max_level = 0;
+    for (int i = 0; i < contextual_effects_.size(); ++i) {
+      const ContextualEffect &effect(contextual_effects_[i]);
+      if (contextual) {
+        if (effect.models_context_factor(factor)) {
+          max_level = std::max<int>(
+              max_level,
+              effect.factor_dummy_for_context_factor(factor).level());
+        }
+      } else {
+        if (effect.models_experiment_factor(factor)) {
+          max_level = std::max<int>(
+              max_level,
+              effect.factor_dummy_for_experiment_factor(factor).level());
+        }
+      }
+    }
+    return max_level;
+  }
+
+namespace {
+
+  // Returns true if the effect models a second order interaction
+  // between the two factors.
+  bool models_second_order_interaction(
+      const ContextualEffect &effect,
+      int first_factor, bool first_factor_is_contextual,
+      int second_factor, bool second_factor_is_contextual) {
+    if (effect.order() != 2) return false;
+
+    bool models_first_factor =
+        first_factor_is_contextual
+        ? effect.models_context_factor(first_factor)
+        : effect.models_experiment_factor(first_factor);
+
+    bool models_second_factor =
+        second_factor_is_contextual
+        ? effect.models_context_factor(second_factor)
+        : effect.models_experiment_factor(second_factor);
+
+    return models_first_factor && models_second_factor;
+  }
+
+  std::pair<int, int> extract_levels(
+      const ContextualEffect &effect,
+      int first_factor, bool first_factor_is_contextual,
+      int second_factor, bool second_factor_is_contextual) {
+    int first_level;
+    if (first_factor_is_contextual) {
+      first_level = effect.factor_dummy_for_context_factor(
+          first_factor).level();
+    } else {
+      first_level = effect.factor_dummy_for_experiment_factor(
+          first_factor).level();
+    }
+
+    int second_level;
+    if (second_factor_is_contextual) {
+      second_level = effect.factor_dummy_for_context_factor(
+          second_factor).level();
+    } else {
+      second_level = effect.factor_dummy_for_experiment_factor(
+          second_factor).level();
+    }
+    return std::pair<int, int>(first_level, second_level);
+  }
+
+}  // unnamed namespace
+
+  std::vector<std::vector<int> >
+  ContextualRowBuilder::second_order_interaction_positions(
+      int first_factor, bool first_factor_is_contextual,
+      int second_factor, bool second_factor_is_contextual) const {
+    if (first_factor == second_factor &&
+        first_factor_is_contextual == second_factor_is_contextual) {
+      return std::vector<std::vector<int> >();
+    }
+
+    int max_first_factor_level = find_max_observed_level(
+        first_factor, first_factor_is_contextual);
+    int max_second_factor_level = find_max_observed_level(
+        second_factor, second_factor_is_contextual);
+
+    std::vector<std::vector<int> > ans;
+    for (int i = 0; i < max_first_factor_level; ++i) {
+      ans.push_back(std::vector<int>(max_second_factor_level, -1));
+    }
+
+    bool found_an_interaction = false;
+    for (int i = 0; i < contextual_effects_.size(); ++i) {
+      if (models_second_order_interaction(
+              contextual_effects_[i],
+              first_factor, first_factor_is_contextual,
+              second_factor, second_factor_is_contextual)) {
+        int first_level, second_level;
+        std::tie(first_level, second_level) = extract_levels(
+            contextual_effects_[i],
+            first_factor, first_factor_is_contextual,
+            second_factor, second_factor_is_contextual);
         found_an_interaction = true;
+        ans[first_level - 1][second_level - 1] = i;
       }
     }
     if (!found_an_interaction) {
@@ -950,121 +1288,6 @@ namespace BOOM{
     return ans;
   }
 
-  const Effect & RowBuilder::effect(int i) const {
-    return effects_[i];
-  }
-
-  Vector RowBuilder::build_row(const std::vector<int> &levels)  const {
-    int neffects = effects_.size();
-    Vector ans(neffects);
-    for (int i = 0; i < neffects; ++i) ans[i] = effects_[i].eval(levels);
-    return ans;
-  }
-
-  void RowBuilder::recover_configuration(
-      const ConstVectorView &design_matrix_row,
-      std::vector<int> &configuration) const {
-    for (int i = 0; i < effects_.size(); ++i) {
-      if (design_matrix_row[i] >= .9999) {
-        effects_[i].set_levels(configuration);
-      }
-    }
-  }
-
-  void RowBuilder::recover_configuration(
-      const Vector &design_matrix_row,
-      std::vector<int> &configuration) const {
-    recover_configuration(ConstVectorView(design_matrix_row), configuration);
-  }
-
-  int RowBuilder::dimension() const { return effects_.size(); }
-
-  std::vector<string> RowBuilder::variable_names() const {
-    std::vector<string> ans;
-    int neffects = effects_.size();
-    ans.reserve(neffects);
-    for (int i = 0; i < neffects; ++i) { ans.push_back(effects_[i].name()); }
-    return ans;
-  }
-
-  //======================================================================
-  ContextualRowBuilder::ContextualRowBuilder(
-      const ExperimentStructure &xp,
-      const ExperimentStructure &context,
-      int interaction_order)
-  {
-    ContextualEffect Intercept;
-    contextual_effects_.push_back(Intercept);
-    if (interaction_order == 0) return;
-    if (interaction_order > xp.nfactors() + context.nfactors()) {
-      interaction_order = xp.nfactors() + context.nfactors();
-    }
-
-    std::vector<ContextualEffect> main_effects;
-    for (int factor = 0; factor < xp.nfactors(); ++factor) {
-      for (int level = 1; level < xp.nlevels(factor); ++level) {
-        FactorDummy dummy(
-            factor,
-            level,
-            xp.full_level_name(factor, level, "."));
-        ContextualEffect main_effect(dummy, false);
-        main_effects.push_back(main_effect);
-        contextual_effects_.push_back(main_effect);
-      }
-    }
-    for (int factor = 0; factor < context.nfactors(); ++factor) {
-      for (int level = 1; level < context.nlevels(factor); ++level) {
-        FactorDummy dummy(
-            factor,
-            level, context.full_level_name(factor, level, "."));
-        ContextualEffect main_effect(dummy, true);
-        main_effects.push_back(main_effect);
-        contextual_effects_.push_back(main_effect);
-      }
-    }
-
-    int number_of_main_effects = main_effects.size();
-
-    std::vector<ContextualEffect> last_effects = main_effects;
-    for (int order = 2; order <= interaction_order; ++order) {
-      std::vector<ContextualEffect> current_effects;
-      for (int i = 0; i < number_of_main_effects; ++i) {
-        ContextualEffect main_effect = main_effects[i];
-        for (int j = 0; j < last_effects.size(); ++j) {
-          ContextualEffect lower_order = last_effects[j];
-          if (lower_order.shares_factors_with(main_effect)) {
-            continue;
-          }
-          ContextualEffect interaction(main_effect, lower_order);
-          if (has_effect(interaction)) {
-            continue;
-          }
-          current_effects.push_back(interaction);
-          contextual_effects_.push_back(interaction);
-        }
-      }
-      last_effects = current_effects;
-    }
-  }
-
-  void ContextualRowBuilder::add_effect(const ContextualEffect &e) {
-    contextual_effects_.push_back(e);
-  }
-
-  int ContextualRowBuilder::dimension() const {
-    return contextual_effects_.size();
-  }
-
-  std::vector<string> ContextualRowBuilder::variable_names() const {
-    std::vector<string> ans;
-    int neffects = contextual_effects_.size();
-    ans.reserve(neffects);
-    for (int i = 0; i < neffects; ++i) {
-      ans.push_back(contextual_effects_[i].name());
-    }
-    return ans;
-  }
-
   const ContextualEffect & ContextualRowBuilder::effect(int i) const {
     return contextual_effects_[i];
   }
@@ -1095,5 +1318,70 @@ namespace BOOM{
     }
     return false;
   }
+
+  Selector ContextualRowBuilder::pure_experiment() const {
+    Selector ans(dimension(), false);
+    for (int i = 0; i < contextual_effects_.size(); ++i) {
+      if (contextual_effects_[i].context_order() == 0) {
+        ans.add(i);
+      } else {
+        ans.drop(i);
+      }
+    }
+    return ans;
+  }
+
+  Selector ContextualRowBuilder::pure_context() const {
+    Selector ans(dimension(), false);
+    for (int i = 0; i < contextual_effects_.size(); ++i) {
+      if (contextual_effects_[i].context_order() > 0 &&
+          contextual_effects_[i].experiment_order() == 0) {
+        ans.add(i);
+      } else {
+        ans.drop(i);
+      }
+    }
+    return ans;
+  }
+
+  Selector ContextualRowBuilder::experiment_context_interactions() const {
+    Selector ans(dimension(), false);
+    for (int i = 0; i < contextual_effects_.size(); ++i) {
+      if (contextual_effects_[i].context_order() > 0 &&
+          contextual_effects_[i].experiment_order() > 0) {
+        ans.add(i);
+      } else {
+        ans.drop(i);
+      }
+    }
+    return ans;
+  }
+
+  int ContextualRowBuilder::number_of_experimental_factors() const {
+    int max_experimental_factor = -1;
+    for (int i = 0; i < contextual_effects_.size(); ++i) {
+      const ContextualEffect &effect(contextual_effects_[i]);
+      for (int f = 0; f < effect.experiment_order(); ++f) {
+        const FactorDummy &dummy(effect.experiment_factor(f));
+        max_experimental_factor = std::max<int>(
+            max_experimental_factor, dummy.factor());
+      }
+    }
+    return max_experimental_factor + 1;
+  }
+
+  int ContextualRowBuilder::number_of_contextual_factors() const {
+    int max_contextual_factor = -1;
+    for (int i = 0; i < contextual_effects_.size(); ++i) {
+      const ContextualEffect &effect(contextual_effects_[i]);
+      for (int f = 0; f < effect.context_order(); ++f) {
+        const FactorDummy &dummy(effect.context_factor(f));
+        max_contextual_factor = std::max<int>(
+            max_contextual_factor, dummy.factor());
+      }
+    }
+    return max_contextual_factor + 1;
+  }
+
   //======================================================================
 }
